<?php

namespace Repository;

use Doctrine\ORM\EntityManager;
use Util\Instance\GeneralInstance;
use Teknisa\Model\Traits\TQuery;

class Organizacao extends RepositoryBase
{

    use TQuery;

    const ENTITY_NAME = '\Teknisa\Model\Geral\Entities\Lista';
    /**
     * @var EntityManager
     */
    private $entityManager;

    public function __construct()
    {
        parent::__construct(self::ENTITY_NAME);
        $this->entityManager = GeneralInstance::getEntityManager();
    }

    public function findServerDns($nrorg)
    {
        $query = <<<SQL
       SELECT SERVER_DNS, NMRAZSOCIALORG, NMORGANIZACAO, NRORG
         FROM ORGANIZACAO
        WHERE NRORG = :NRORG
SQL;
        $params = array(
            "NRORG" => $nrorg
        );
        $result = GeneralInstance::getEntityManager()->getConnection()->fetchAll($query, $params);
        return !empty($result) ? $result[0] : array();
    }

    public function saveServeUrl($nrorg, $serveUrl)
    {
        $query = <<<SQL
        UPDATE ORGANIZACAO
           SET SERVER_DNS = :SERVER_DNS
         WHERE NRORG = :NRORG
SQL;
        $params = array(
            "NRORG" => $nrorg,
            "SERVER_DNS" => $serveUrl,
        );
        GeneralInstance::getEntityManager()->getConnection()->executeQuery($query, $params);

    }

    public function getInfoOperador($operador, $password)
    {
        $query =
            <<<SQL
                SELECT CDOPERADOR AS "ID", NMOPERADOR AS "NAME", NRORG AS "ORGANIZATION_ID", DSEMAILOPER AS "EMAIL",
                       IDIDIOMA AS "IDIDIOMA", NMACESSO AS "NMACESSO", NMCOMPLOPER AS "NMCOMPLOPER", 
                       CDEMPRESA AS "CDEMPRESA", NRPARCNEGOCIO AS "NRPARCNEGOCIO",
                       NRORG AS "NRORG", NRORGTRAB AS "NRORGTRAB", NRESTRUTTRAB AS "NRESTRUTTRAB", 
                       CDFILIALSELECIONADA AS "CDFILIALSELECIONADA", NRORGOPER AS "NRORGOPER",
                       CASE WHEN IDOPERATIVO = 'A'
                            THEN 'Y'
                            ELSE 'N'
                        END AS "IS_ACTIVE"
                  FROM OPERADOR
                 WHERE (UPPER(NMACESSO) = UPPER(:OPERADOR) OR DSEMAILOPER = :OPERADOR)
                   AND CDSENHAOPERWEB = :PASSWORD
SQL;

        $params = array(
            'OPERADOR' => $operador,
            'PASSWORD' => $password,
        );
        $result = GeneralInstance::getConnectionCustom()->updateSaasConnection()->getConnection()->fetchAll($query,$params);
        return !empty($result) ? $result[0] : array();
    }

    public function findOmProdutoByDevOpsId($devOpsId)
    {
        $query = <<<SQL
       SELECT ID, NMPRODUTO
         FROM OM_PRODUTO
        WHERE NREXTERNAL_PRODUCT_ID = :ID
SQL;
        $params = array(
            "ID" => $devOpsId
        );
        return GeneralInstance::getEntityManager()->getConnection()->fetchAssoc($query, $params);
    }
}
